@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: build_boilerplate2.py 11589 2019-05-28 17:47:23Z Lavender $
+# $Id: build_boilerplate2.py 11654 2019-07-17 20:42:48Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2019-05-29 01:47:23 +0800 (週三, 29 五月 2019) $
-# $Revision: 11589 $
+# $Date: 2019-07-18 04:42:48 +0800 (週四, 18 七月 2019) $
+# $Revision: 11654 $
 
 import os
 import re
@@ -479,11 +479,12 @@ class Command(BaseCommand):
             "Workaround for fixing Django CMS issues")
 
         addJ = etree.Element('script')
-        addJ.set('src', 'js/FixTemplate.js')
+        addJ.set('src', hashlib.md5(toBytes('js/FixTemplate.js')).hexdigest())
         addJ.tail = '\n'
 
         addContext = etree.Element('script')
-        addContext.set('src', 'js/CMSContext.js')
+        addContext.set(
+            'src', hashlib.md5(toBytes('js/CMSContext.js')).hexdigest())
         addContext.tail = '\n'
 
         metaDescription = etree.Element('meta')
